@@ -1,5 +1,3 @@
-.\" $XdotOrg: xc/programs/xdm/xdm.man,v 1.3 2004/07/26 22:56:33 herrb Exp $
-.\" $Xorg: xdm.man,v 1.4 2001/02/09 02:05:41 xorgcvs Exp $
 .\" Copyright 1988, 1994, 1998  The Open Group
 .\"
 .\" Permission to use, copy, modify, distribute, and sell this software and its
@@ -24,7 +22,6 @@
 .\" other dealings in this Software without prior written authorization
 .\" from The Open Group.
 .\"
-.\" $XFree86: xc/programs/xdm/xdm.man,v 3.28 2004/01/09 00:25:23 dawes Exp $
 .\"
 .TH XDM 1 __xorgversion__
 .SH NAME
@@ -208,10 +205,10 @@ for a description of this resource.
 Specifies the value for the \fBDisplayManager.requestPort\fP resource.  This
 sets the port-number which
 .I xdm
-will monitor for XDMCP requests.  As XDMCP
-uses the registered well-known UDP port 177, this resource should
-not be changed except for debugging. If set to 0 xdm will not listen
-for XDMCP or Chooser requests.
+will monitor for XDMCP requests.  If set to 0, xdm will not listen
+for XDMCP or Chooser requests.  As XDMCP uses the registered well-known
+UDP port 177, this resource should not be changed to a value other than 0,
+except for debugging.
 .IP "\fB\-session\fP \fIsession_program\fP"
 Specifies the value for the \fBDisplayManager*session\fP resource.  This
 indicates the program to run as the session after the user has logged in.
@@ -306,7 +303,7 @@ uses the \fIlockf\fP library call, while on BSD it uses \fIflock.\fP
 This names a directory under which
 .I xdm
 stores authorization files while initializing the session.  The
-default value is \fI XDMDIR.\fP
+default value is \fI XDMXAUTHDIR.\fP
 Can be overridden for specific displays by
 DisplayManager.\fIDISPLAY\fP.authFile.
 .IP \fBDisplayManager.autoRescan\fP
@@ -374,7 +371,7 @@ algorithm is used instead.
 .IP \fBDisplayManager.greeterLib\fP
 On systems that support a dynamically-loadable greeter library, the
 name of the library.  The default is
-\fI XDMDIR/libXdmGreet.so\fP.
+\fI DEF_GREETER_LIB\fP.
 .IP \fBDisplayManager.choiceTimeout\fP
 Number of seconds to wait for display to respond after user has
 selected a host from the chooser.  If the display sends an XDMCP
@@ -497,16 +494,11 @@ sets the PATH environment variable for the session to this value.  It should
 be a colon separated list of directories; see
 .IR sh (1)
 for a full description.
-``:/bin:/usr/bin:BINDIR:/usr/ucb''
-is a common setting.
-The default value can be specified at build time in the X system
-configuration file with DefaultUserPath.
+The default value is ``DEF_USER_PATH''.
 .IP "\fBDisplayManager.\fP\fIDISPLAY\fP\fB.systemPath\fP"
 .I Xdm
 sets the PATH environment variable for the startup and reset scripts to the
-value of this resource.  The default for this resource is specified
-at build time by the DefaultSystemPath entry in the system configuration file;
-``/etc:/bin:/usr/bin:BINDIR:/usr/ucb'' is a common choice.
+value of this resource.  The default for this resource is ``DEF_SYSTEM_PATH''.
 Note the absence of ``.'' from this entry.  This is a good practice to
 follow for root; it avoids many common Trojan Horse system penetration
 schemes.
@@ -552,7 +544,7 @@ authorization mechanisms are supported, so
 \fBauthName\fP is ignored in this case.  When \fBauthorize\fP is set for a
 display and authorization is not available, the user is informed by having a
 different message displayed in the login widget.  By default, \fBauthorize\fP
-is ``true.''  \fBauthName\fP is ``MIT-MAGIC-COOKIE-1,'' or, if
+is ``true,''  \fBauthName\fP is ``MIT-MAGIC-COOKIE-1,'' or, if
 XDM-AUTHORIZATION-1 is available, ``XDM-AUTHORIZATION-1\0MIT-MAGIC-COOKIE-1.''
 .IP \fBDisplayManager.\fP\fIDISPLAY\fP\fB.authFile\fP
 This file is used to communicate the authorization data from
@@ -797,13 +789,13 @@ LISTEN 10.11.12.13	# Listen only on this interface, as long
 .fi
 .SH "IPv6 MULTICAST ADDRESS SPECIFICATION"
 .PP
-The Internet Assigned Numbers Authority has has assigned 
-ff0\fIX\fP:0:0:0:0:0:0:12b as the permanently assigned range of 
+The Internet Assigned Numbers Authority has has assigned
+ff0\fIX\fP:0:0:0:0:0:0:12b as the permanently assigned range of
 multicast addresses for XDMCP. The \fIX\fP in the prefix may be replaced
-by any valid scope identifier, such as 1 for Node-Local, 2 for Link-Local,
-5 for Site-Local, and so on.  (See IETF RFC 2373 or its replacement for 
+by any valid scope identifier, such as 1 for Interface-Local, 2 for Link-Local,
+5 for Site-Local, and so on.  (See IETF RFC 4291 or its replacement for
 further details and scope definitions.)  xdm defaults to listening on the
-Link-Local scope address ff02:0:0:0:0:0:0:12b to most closely match the 
+Link-Local scope address ff02:0:0:0:0:0:0:12b to most closely match the
 old IPv4 subnet broadcast behavior.
 .SH "LOCAL SERVER SPECIFICATION"
 .PP
@@ -946,20 +938,20 @@ statements to produce different displays depending on color depth or other
 variables.
 .PP
 .I Xdm
-can be compiled with support for the 
-.IR Xft (__libmansuffix__) 
-library for font rendering.   If this support is present, font faces are 
-specified using the resources with names ending in "face" in the
-fontconfig face format described in the 
+can be compiled with support for the
+.IR Xft (__libmansuffix__)
+library for font rendering.   If this support is present, font faces are
+specified using the resources with names ending in ``face'' in the
+fontconfig face format described in the
 .I Font Names
 section of
 .IR fonts.conf (__filemansuffix__).
-If not, then fonts are specified using the resources with names ending in 
-"font" in the traditional 
-.I X Logical Font Description 
-format described in the 
+If not, then fonts are specified using the resources with names ending
+in ``font'' in the traditional
+.I X Logical Font Description
+format described in the
 .I Font Names
-section of 
+section of
 .IR X (__miscmansuffix__).
 .IP "\fBxlogin.Login.width, xlogin.Login.height, xlogin.Login.x, xlogin.Login.y\fP"
 The geometry of the Login widget is normally computed automatically.  If you
@@ -967,7 +959,7 @@ wish to position it elsewhere, specify each of these resources.
 .IP "\fBxlogin.Login.foreground\fP"
 The color used to display the input typed by the user.
 .IP "\fBxlogin.Login.face\fP"
-The face used to display the input typed by the user when built with Xft 
+The face used to display the input typed by the user when built with Xft
 support.  The default is ``Serif-18''.
 .IP "\fBxlogin.Login.font\fP"
 The font used to display the input typed by the user when not built with Xft
@@ -1043,10 +1035,10 @@ The default for both is the foreground color, providing a flat appearance.
 frameWidth is the width in pixels of the area
 around the greeter frame drawn in hiColor and shdColor.
 .IP "\fBxlogin.Login.innerFramesWidth\fP"
-innerFramesWidth is the width in pixels of the 
+innerFramesWidth is the width in pixels of the
 area around text input areas drawn in hiColor and shdColor.
 .IP "\fBxlogin.Login.sepWidth\fP"
-sepWidth is the width in pixels of the 
+sepWidth is the width in pixels of the
 bezeled line between the greeting and input areas
 drawn in hiColor and shdColor.
 .IP "\fBxlogin.Login.allowRootLogin\fP"
@@ -1058,6 +1050,10 @@ If set to ``true'', allow an otherwise failing password match to succeed
 if the account does not require a password at all.
 The default is ``false'', so only users that have passwords assigned can
 log in.
+.IP "\fBxlogin.Login.echoPasswd\fP"
+If set to ``true'', stars will be rendered instead of the password itself,
+i.e. '***...'.
+The default is ``false''.
 .IP "\fBxlogin.Login.translations\fP"
 This specifies the translations used for the login widget.  Refer to the X
 Toolkit documentation for a complete discussion on translations.  The default
@@ -1145,7 +1141,7 @@ root when the user logs in.
 It is typically a shell script.
 Since it is run as root, \fIXstartup\fP should be
 very careful about security.  This is the place to put commands which add
-entries to \fI/etc/utmp\fP
+entries to \fIutmp\fP or \fIwtmp\fP files,
 (the \fIsessreg\fP program may be useful here),
 mount users' home directories from file servers,
 or abort the session if logins are not
@@ -1294,8 +1290,8 @@ example.  Don't forget that the file must have execute permission.
 Symmetrical with \fIXstartup\fP,
 the \fIXreset\fP script is run after the user session has
 terminated.  Run as root, it should contain commands that undo
-the effects of commands in \fIXstartup,\fP removing entries
-from \fI/etc/utmp\fP
+the effects of commands in \fIXstartup,\fP updating entries
+in \fIutmp\fP or \fIwtmp\fP files,
 or unmounting directories from file servers.  The environment
 variables that were passed to \fIXstartup\fP are also
 passed to \fIXreset\fP.
@@ -1431,7 +1427,7 @@ the default server
 .I BINDIR/xterm
 the default session program and failsafe client
 .TP 20
-.I XDMDIR/A<display>\-<suffix>
+.I XDMXAUTHDIR/A<display>\-<suffix>
 the default place for authorization files
 .TP 20
 .I /tmp/K5C<display>
@@ -1449,5 +1445,7 @@ Kerberos credentials cache
 .IR fonts.conf (__filemansuffix__).
 .br
 .I "X Display Manager Control Protocol"
+.br
+.RI "IETF RFC 4291: " "IP Version 6 Addressing Architecture" .
 .SH AUTHOR
 Keith Packard, MIT X Consortium
